.. _errors:

Errors
======

django-reversion defines several custom errors.


.. _RegistrationError:

reversion.RegistrationError
---------------------------

Something went wrong with the :ref:`registration-api`.


.. _RevisionManagementError:

reversion.RevisionManagementError
---------------------------------

Something went wrong using the :ref:`revision-api`.


.. _RevertError:

reversion.RevertError
---------------------

Something went wrong reverting a revision.
